//[mahjong-utils](../../../index.md)/[mahjongutils.hanhu](../index.md)/[ParentPoint](index.md)/[tsumo](tsumo.md)

# tsumo

[common]\
val [tsumo](tsumo.md): [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)

自摸各家点数
